MultiLinearTuckerInteraction
============================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: MultiLinearTuckerInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MultiLinearTuckerInteraction.entity_shape
      ~MultiLinearTuckerInteraction.relation_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultiLinearTuckerInteraction.func
      ~MultiLinearTuckerInteraction.reset_parameters

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_shape
   .. autoattribute:: relation_shape

   .. rubric:: Methods Documentation

   .. automethod:: func
   .. automethod:: reset_parameters
